@@ -1,5 +1,6 @@
 from pydantic import BaseModel
 
+from ..merchant.merchant import Merchant
 from .feature import UserFeature
 from .income import UserIncome
 from .notification import UserNotification
@@ -9,10 +10,9 @@ from .store import UserStore
 class UserState(BaseModel):
     active: bool
     stores: list[UserStore]
-    income: list[UserIncome]
-    features: list[str]
-    active_features: UserFeature
-    active_features_details: UserFeature
+    incomes: list[UserIncome]
+    features: list[UserFeature]
+    active_feature: UserFeature
     population: int
-    merchants: list[str]
+    merchants: list[Merchant]
     notifications: list[UserNotification]
